@@ -26,9 +26,6 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#ifdef G_OS_WIN32
-#include <io.h>
-#endif
 
 #include <string.h>
 #include <fcntl.h>
@@ -39,21 +36,25 @@
 #include "gtksourcelanguage-private.h"
 #include "gtksourcelanguage.h"
 
+#ifdef G_OS_WIN32
+#include <io.h>
+#endif
+
 /**
  * SECTION:language
  * @Short_description: Represents a syntax highlighted language
  * @Title: GtkSourceLanguage
  * @See_also: #GtkSourceLanguageManager
  *
- * #GtkSourceLanguage encapsulates syntax and highlighting styles for a
- * particular language. Use #GtkSourceLanguageManager to obtain a
- * #GtkSourceLanguage instance, and gtk_source_buffer_set_language() to apply it
- * to a #GtkSourceBuffer.
+ * A #GtkSourceLanguage represents a programming or markup language, affecting
+ * syntax highlighting and [context classes][context-classes].
+ *
+ * Use #GtkSourceLanguageManager to obtain a #GtkSourceLanguage instance, and
+ * gtk_source_buffer_set_language() to apply it to a #GtkSourceBuffer.
  */
 
 #define DEFAULT_SECTION _("Others")
 
-/* Properties */
 enum {
 	PROP_0,
 	PROP_ID,
@@ -123,8 +124,12 @@ _gtk_source_language_new_from_file (const gchar              *filename,
         }
 	else
 	{
-		g_warning("Unable to open '%s'", filename);
+		g_warning ("Unable to open '%s'", filename);
 
+		if (fd != -1)
+		{
+			close (fd);
+		}
     	}
 
 	if (lang != NULL)
@@ -227,7 +232,8 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 						 	      "Language id",
 							      "Language id",
 							      NULL,
-							      G_PARAM_READABLE));
+							      G_PARAM_READABLE |
+							      G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (object_class,
 					 PROP_NAME,
@@ -235,7 +241,8 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 						 	      "Language name",
 							      "Language name",
 							      NULL,
-							      G_PARAM_READABLE));
+							      G_PARAM_READABLE |
+							      G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (object_class,
 					 PROP_SECTION,
@@ -243,7 +250,8 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 						 	      "Language section",
 							      "Language section",
 							      NULL,
-							      G_PARAM_READABLE));
+							      G_PARAM_READABLE |
+							      G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (object_class,
 					 PROP_HIDDEN,
@@ -251,7 +259,8 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 							       "Hidden",
 							       "Whether the language should be hidden from the user",
 							       FALSE,
-							       G_PARAM_READABLE));
+							       G_PARAM_READABLE |
+							       G_PARAM_STATIC_STRINGS));
 }
 
 static void
